@@ -4,23 +4,23 @@ context("Tests reading of a credentials file")
 
 test_that("default_credentials_file() works", {
     skip_on_cran()
-    expect_true(is.character(default_credentials_file()), label = "default_credentials_file() returns path")
+    expect_is(default_credentials_file(), "character", label = "default_credentials_file() returns path")
 })
 
 test_that("read_credentials() works", {
     skip_on_cran()
-    expect_true(inherits(read_credentials(file = "credentials"), "aws_credentials"), label = "Read credentials correctly")
+    expect_is(read_credentials(file = "credentials"), "aws_credentials", label = "Read credentials correctly")
     alice <- read_credentials(file = "credentials")[["Alice"]]
     bob <- read_credentials(file = "credentials")[["Bob"]]
-    expect_true(bob[["AWS_SECRET_ACCESS_KEY"]] == "Bob_secret_access_key", label = "final line value read correctly")
+    expect_equal(bob[["AWS_SECRET_ACCESS_KEY"]], "Bob_secret_access_key", label = "final line value read correctly")
     expect_false(identical(alice, bob), label = "Read distinct profiles correctly")
 })
 
 test_that("read_credentials() works even absent EOL character", {
     skip_on_cran()
     cred <- read_credentials(file = "credentials-no-eol-char")
-    expect_true(inherits(cred, "aws_credentials"), label = "Read credentials successfully")
-    expect_true(cred[["Bob"]][["AWS_SECRET_ACCESS_KEY"]] == "Bob_secret_access_key", label = "final line value read correctly")
+    expect_is(cred, "aws_credentials", label = "Read credentials successfully")
+    expect_equal(cred[["Bob"]][["AWS_SECRET_ACCESS_KEY"]], "Bob_secret_access_key", label = "final line value read correctly")
 })
 
 test_that("read_credentials() fails when file is missing", {
@@ -46,10 +46,10 @@ test_that("use_credentials() sets environment variables correctly", {
     
     # tests
     use_credentials(profile = "default", file = "credentials")
-    expect_true(Sys.getenv("AWS_ACCESS_KEY_ID") == "ACCESS_KEY")
-    expect_true(Sys.getenv("AWS_SECRET_ACCESS_KEY") == "SECRET_KEY")
-    expect_true(Sys.getenv("AWS_SESSION_TOKEN") == "TOKEN")
-    expect_true(Sys.getenv("AWS_DEFAULT_REGION") == "")
+    expect_equal(Sys.getenv("AWS_ACCESS_KEY_ID"), "ACCESS_KEY")
+    expect_equal(Sys.getenv("AWS_SECRET_ACCESS_KEY"), "SECRET_KEY")
+    expect_equal(Sys.getenv("AWS_SESSION_TOKEN"), "TOKEN")
+    expect_equal(Sys.getenv("AWS_DEFAULT_REGION"), "")
     
     # restore environment variables
     do.call("Sys.setenv", as.list(e))
